package com.shirodemo.controller;

import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.IncorrectCredentialsException;
import org.apache.shiro.authc.UnknownAccountException;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.subject.Subject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;

/**
 *
 */
@Controller
public class LoginController {

    // 登录的Controller,也可以说是处理身份认证
    @PostMapping("/login")
    public String login(String username, String password) {
        // 获取主体对象/当前用户
        Subject subject = SecurityUtils.getSubject();
        // 封装成Token
        UsernamePasswordToken token = new UsernamePasswordToken(username, password);
        try {
            // 调用login方法去认证
            subject.login(token);
            System.out.println("登陆成功！");
            // 重定向到首页
            return "redirect:/index.html";
        } catch (UnknownAccountException e) {
            System.out.println("用户名不存在！");
            e.printStackTrace();
        } catch (IncorrectCredentialsException e) {
            System.out.println("密码错误！");
            e.printStackTrace();
        } catch (AuthenticationException e) {
            System.out.println("认证时出现异常！");
            e.printStackTrace();
        }
        return "redirect:/login.html";
    }

    /**
     * 退出认证
     */
    @GetMapping("/logout")
    public String logout(){
        Subject subject = SecurityUtils.getSubject();

        // 调用subject的logout方法退出登录，
        subject.logout();

        return "redirect:/login.html";
    }
}